paclo.capture

Internal managed capture implementation.

This namespace owns the mutable boundary around a libpcap handle. Public callers use the data-first facade in paclo.core.

Internal managed capture implementation.

This namespace owns the mutable boundary around a libpcap handle. Public
callers use the data-first facade in `paclo.core`.
raw docstring

-await-close!clj

(-await-close! capture)
source

-packet-seqclj

(-packet-seq capture)
source

-request-stop!clj

(-request-stop! capture reason)
source

-snapshotclj

(-snapshot capture)
source

packet-seqclj

(packet-seq capture)

Return the single-consumer packet sequence for a managed capture.

Return the single-consumer packet sequence for a managed capture.
sourceraw docstring

startclj

(start opts)

Start one managed capture and return an opaque Closeable handle.

Start one managed capture and return an opaque Closeable handle.
sourceraw docstring

statsclj

(stats capture)

Return a data-only snapshot for a managed capture.

Return a data-only snapshot for a managed capture.
sourceraw docstring

stop!clj

(stop! capture)

Request asynchronous, idempotent capture termination.

Request asynchronous, idempotent capture termination.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries