paclo.stream.impl

Internal bounded fan-out runtime.

This namespace backs paclo.stream but remains an implementation detail and is not part of Paclo's public compatibility contract.

Internal bounded fan-out runtime.

This namespace backs `paclo.stream` but remains an implementation detail and
is not part of Paclo's public compatibility contract.
raw docstring

-abandon!clj

(-abandon! buffer)
source

-close!clj

(-close! buffer)
source

-depthclj

(-depth buffer)
source

-enqueue!clj

(-enqueue! buffer mode boxed)
source

-take!clj

(-take! buffer)
source

await!clj

(await! fanout)
(await! fanout timeout-ms)

Wait for the internal dispatcher. Return true when it has stopped.

Wait for the internal dispatcher. Return true when it has stopped.
sourceraw docstring

branchclj

(branch fanout id)

Acquire one internal Seqable, IReduceInit, and Closeable branch handle.

Acquire one internal Seqable, IReduceInit, and Closeable branch handle.
sourceraw docstring

startclj

(start source branches)
(start source
       branches
       {:keys [cancel! close-timeout-ms]
        :or {close-timeout-ms default-close-timeout-ms}})

Start an internal core.async-backed fan-out runtime.

source must be seqable. Every branch requires an explicit :buffer-mode and has a bounded :buffer-cap. :cancel! must unblock an infinite or externally waiting source when the runtime is closed.

Start an internal core.async-backed fan-out runtime.

`source` must be seqable. Every branch requires an explicit
`:buffer-mode` and has a bounded `:buffer-cap`. `:cancel!` must unblock an
infinite or externally waiting source when the runtime is closed.
sourceraw docstring

statsclj

(stats fanout)

Return a data-only snapshot of the internal fan-out runtime.

Return a data-only snapshot of the internal fan-out runtime.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries