Internal managed capture implementation.
This namespace owns the mutable boundary around a libpcap handle. Public
callers use the data-first facade in paclo.core.
Internal managed capture implementation. This namespace owns the mutable boundary around a libpcap handle. Public callers use the data-first facade in `paclo.core`.
(packet-seq capture)Return the single-consumer packet sequence for a managed capture.
Return the single-consumer packet sequence for a managed capture.
(start opts)Start one managed capture and return an opaque Closeable handle.
Start one managed capture and return an opaque Closeable handle.
(stats capture)Return a data-only snapshot for a managed capture.
Return a data-only snapshot for a managed capture.
(stop! capture)Request asynchronous, idempotent capture termination.
Request asynchronous, idempotent capture termination.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |