(apply! m)Apply all hooks to message map m (execution order = registration order). Hooks are isolated; exceptions are caught and ignored. Only map return values are applied; others are ignored. Skips when :decoded is absent or :decode-error is present (defensive guard).
Apply all hooks to message map m (execution order = registration order). Hooks are isolated; exceptions are caught and ignored. Only map return values are applied; others are ignored. Skips when :decoded is absent or :decode-error is present (defensive guard).
(installed)Return a sequence of installed hook keys in execution order.
Return a sequence of installed hook keys in execution order.
(register! k f)Register a post-decode hook. k: keyword/ident for later management f: (fn [m] m') — take whole message map (with :decoded) and return updated map. Overwrites existing key and keeps the latest position.
Register a post-decode hook. k: keyword/ident for later management f: (fn [m] m') — take whole message map (with :decoded) and return updated map. Overwrites existing key and keeps the latest position.
(unregister! k)Remove a previously registered hook by key.
Remove a previously registered hook by key.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |