Internal low-allocation flow projection for Ethernet IP packets.
Internal low-allocation flow projection for Ethernet IP packets.
(packet->flow frame)Project Ethernet IPv4/IPv6 bytes into numeric flow fields.
IPv4 addresses are unsigned values in longs. IPv6 addresses are
[high-long low-long] pairs. Throws ex-info for unsupported or truncated
packets so the public facade can represent the failure as data.
Project Ethernet IPv4/IPv6 bytes into numeric flow fields. IPv4 addresses are unsigned values in longs. IPv6 addresses are `[high-long low-long]` pairs. Throws `ex-info` for unsupported or truncated packets so the public facade can represent the failure as data.
(project-packet packet)Project a capture packet map into metadata plus numeric flow fields.
The returned array-map deliberately excludes the raw bytes.
Project a capture packet map into metadata plus numeric flow fields. The returned array-map deliberately excludes the raw bytes.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |